]> sigrok.org Git - libsigrok.git/blobdiff - device.c
libsigrok: Rename open/close to opendev/closedev.
[libsigrok.git] / device.c
index bf87e811e90c6ffb9530214b0fcf381215bde610..a1556aa4e37244cb57bdf97f7ec644771cc70b7a 100644 (file)
--- a/device.c
+++ b/device.c
@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <glib.h>
 #include <sigrok.h>
+#include <sigrok-internal.h>
 
 extern struct sr_global *global;
 
@@ -48,7 +49,7 @@ int sr_device_plugin_init(struct sr_device_plugin *plugin)
 {
        int num_devices, num_probes, i;
 
-       g_message("initializing %s plugin", plugin->name);
+       sr_info("initializing %s plugin", plugin->name);
        num_devices = plugin->init(NULL);
        for (i = 0; i < num_devices; i++) {
                num_probes = (int)plugin->get_device_info(i, SR_DI_NUM_PROBES);
@@ -64,8 +65,8 @@ void sr_device_close_all(void)
 
        while (devices) {
                device = devices->data;
-               if (device->plugin && device->plugin->close)
-                       device->plugin->close(device->plugin_index);
+               if (device->plugin && device->plugin->closedev)
+                       device->plugin->closedev(device->plugin_index);
                sr_device_destroy(device);
        }
 }
@@ -85,7 +86,11 @@ struct sr_device *sr_device_new(struct sr_device_plugin *plugin, int plugin_inde
        struct sr_device *device;
        int i;
 
-       device = g_malloc0(sizeof(struct sr_device));
+       if (!(device = g_try_malloc0(sizeof(struct sr_device)))) {
+               sr_err("dev: %s: device malloc failed", __func__);
+               return NULL;
+       }
+
        device->plugin = plugin;
        device->plugin_index = plugin_index;
        devices = g_slist_append(devices, device);
@@ -146,14 +151,20 @@ void sr_device_probe_clear(struct sr_device *device, int probenum)
        }
 }
 
-void sr_device_probe_add(struct sr_device *device, char *name)
+void sr_device_probe_add(struct sr_device *device, const char *name)
 {
        struct sr_probe *p;
        char probename[16];
        int probenum;
 
        probenum = g_slist_length(device->probes) + 1;
-       p = g_malloc0(sizeof(struct sr_probe));
+
+       if (!(p = g_try_malloc0(sizeof(struct sr_probe)))) {
+               sr_err("dev: %s: p malloc failed", __func__);
+               // return SR_ERR_MALLOC;
+               return; /* FIXME: should return int. */
+       }
+
        p->index = probenum;
        p->enabled = TRUE;
        if (name) {
@@ -183,8 +194,9 @@ struct sr_probe *sr_device_probe_find(struct sr_device *device, int probenum)
        return found_probe;
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
-void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
+/* TODO: return SR_ERR if probenum not found */
+void sr_device_probe_name(struct sr_device *device, int probenum,
+                         const char *name)
 {
        struct sr_probe *p;
 
@@ -197,7 +209,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
        p->name = g_strdup(name);
 }
 
/* TODO: return SIGROK_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {
        struct sr_probe *p;
@@ -215,8 +227,9 @@ void sr_device_trigger_clear(struct sr_device *device)
        }
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
-void sr_device_trigger_set(struct sr_device *device, int probenum, char *trigger)
+/* TODO: return SR_ERR if probenum not found */
+void sr_device_trigger_set(struct sr_device *device, int probenum,
+                          const char *trigger)
 {
        struct sr_probe *p;
 
@@ -236,7 +249,7 @@ gboolean sr_device_has_hwcap(struct sr_device *device, int hwcap)
        int *capabilities, i;
 
        if (!device || !device->plugin)
-               return;
+               return FALSE;
 
        if ((capabilities = device->plugin->get_capabilities()))
                for (i = 0; capabilities[i]; i++)
@@ -197,7 +209,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
+/* TODO: return SR_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {